summaryrefslogtreecommitdiffstats
path: root/webkit/port/bindings/v8/v8_proxy.cpp
diff options
context:
space:
mode:
authorfqian@google.com <fqian@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-10 19:52:54 +0000
committerfqian@google.com <fqian@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-10 19:52:54 +0000
commitbf5e7dbe6389d8e9a2b0d582c4b84b867599f962 (patch)
tree7bc040390dc6a13cfb0c6c56aa3073ccd06aa371 /webkit/port/bindings/v8/v8_proxy.cpp
parent81c2122f16c82b52c19b474775d2a15aa065e77a (diff)
downloadchromium_src-bf5e7dbe6389d8e9a2b0d582c4b84b867599f962.zip
chromium_src-bf5e7dbe6389d8e9a2b0d582c4b84b867599f962.tar.gz
chromium_src-bf5e7dbe6389d8e9a2b0d582c4b84b867599f962.tar.bz2
Fix issue 580 that JavaScript cannot talk to Java applets.
The cause was that the DOM binding code didn't treat HTMLAppletElement as a plugin element. I couldn't add a layout test because it requires Java plugin installed to run. Review URL: http://codereview.chromium.org/1900 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@2006 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/port/bindings/v8/v8_proxy.cpp')
-rw-r--r--webkit/port/bindings/v8/v8_proxy.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/webkit/port/bindings/v8/v8_proxy.cpp b/webkit/port/bindings/v8/v8_proxy.cpp
index 9b595c1..8c0be2e 100644
--- a/webkit/port/bindings/v8/v8_proxy.cpp
+++ b/webkit/port/bindings/v8/v8_proxy.cpp
@@ -1158,10 +1158,10 @@ v8::Persistent<v8::FunctionTemplate> V8Proxy::GetTemplate(
V8Custom::kDocumentMinimumInternalFieldCount);
break;
}
- case V8ClassIndex::HTMLEMBEDELEMENT:
- // fall through
+ case V8ClassIndex::HTMLAPPLETELEMENT: // fall through
+ case V8ClassIndex::HTMLEMBEDELEMENT: // fall through
case V8ClassIndex::HTMLOBJECTELEMENT:
// Follow through. Both HTMLEmbedElement and HTMLObjectElement are
// inherited from HTMLPlugInElement, and they share the same property
// handling code.
desc->InstanceTemplate()->SetNamedPropertyHandler(
@@ -1158,10 +1158,10 @@ v8::Persistent<v8::FunctionTemplate> V8Proxy::GetTemplate(
case V8ClassIndex::HTMLOBJECTELEMENT:
- // Follow through. Both HTMLEmbedElement and HTMLObjectElement are
+ // HTMLAppletElement, HTMLEmbedElement and HTMLObjectElement are
// inherited from HTMLPlugInElement, and they share the same property
// handling code.